@@ -53,7 +53,11 @@ def upload_s3(key_bucket, ssm_key_alias, key_name, encoded_ciphertext, s3_client
 
 
 def get_aws_config_from_bucket(s3_client, ssm_key, key_bucket):
-    s3_key = ssm_key + '.json'
+    if '.json' not in ssm_key:
+        s3_key = ssm_key + '.json'
+    else:
+        s3_key = ssm_key
+
     response = s3_client.get_object(
         Bucket=key_bucket,
         Key=s3_key
@@ -62,7 +66,7 @@ def get_aws_config_from_bucket(s3_client, ssm_key, key_bucket):
     return decoded_res
 
 
-def decrypt_text_with_kms(key_bucket, ssm_key, kms_client=None, s3_client=None):
+def decrypt_text_with_kms(key_bucket, saved_bucket_key, kms_client=None, s3_client=None):
     if kms_client is None:
         kms_client = boto3.client('kms',
                                   aws_access_key_id=None,
@@ -74,8 +78,7 @@ def decrypt_text_with_kms(key_bucket, ssm_key, kms_client=None, s3_client=None):
                                  aws_secret_access_key=None
                                  )
 
-    print(key_bucket)
-    endcoded_text = get_aws_config_from_bucket(s3_client, ssm_key, key_bucket)
+    endcoded_text = get_aws_config_from_bucket(s3_client, saved_bucket_key, key_bucket)
     cipher_text_blob = base64.b64decode(endcoded_text)
     decrypt_text = kms_client.decrypt(
         CiphertextBlob=bytes(cipher_text_blob)
